@@ -1,5 +1,5 @@
 package ETL::Yertl::Command::yts;
-our $VERSION = '0.031';
+our $VERSION = '0.032';
 # ABSTRACT: Read/Write time series data
 
 #pod =head1 SYNOPSIS
@@ -42,19 +42,8 @@ sub main {
 
     my $db = load_module( adapter => $db_type )->new( $db_spec );
 
-    if ( -t STDIN ) {
-        die "Must give a metric\n" unless $metric;
-        my $out_fmt = load_module( format => 'default' )->new;
-        my @points = $db->read_ts( $metric, $field, $opt{tags} );
-        if ( $opt{short} ) {
-            my %ts = map { $_->{timestamp} => $_->{value} } @points;
-            print $out_fmt->write( \%ts );
-        }
-        else {
-            print $out_fmt->write( $_ ) for @points;
-        }
-    }
-    else {
+    # Write metrics
+    if ( !-t STDIN && !-z *STDIN ) {
         if ( $opt{short} ) {
             die "Must give a metric\n" unless $metric;
         }
@@ -94,6 +83,19 @@ sub main {
 
         #; say "Wrote $count points";
     }
+    # Read metrics
+    else {
+        die "Must give a metric\n" unless $metric;
+        my $out_fmt = load_module( format => 'default' )->new;
+        my @points = $db->read_ts( $metric, $field, $opt{tags} );
+        if ( $opt{short} ) {
+            my %ts = map { $_->{timestamp} => $_->{value} } @points;
+            print $out_fmt->write( \%ts );
+        }
+        else {
+            print $out_fmt->write( $_ ) for @points;
+        }
+    }
 
     return 0;
 }
@@ -110,7 +112,7 @@ ETL::Yertl::Command::yts - Read/Write time series data
 
 =head1 VERSION
 
-version 0.031
+version 0.032
 
 =head1 SYNOPSIS
 
